@@ -484,7 +484,7 @@ print "WHAT IS THISSSSS=$self->{ppk_file}\n";
       my $hadoop_flag=0;my $count=0;
       foreach my $line (reverse @lines) {
          $count++;
-         if ($line=~/GNU.io/) {
+         if ($line=~/GNU.io/ or $line=~/clipbucket[.]com/i) {
             next;
          } elsif (
                $line=~/ACCESS (?:HADOOP|KALI|OPENLDAP|CATALYST|GNU|CLIP)/) {
@@ -558,8 +558,15 @@ sub fullauto_button {
    }
    EVT_WXP_PROCESS_STREAM_EXIT($self, \&evt_process_exit);
    unless ((-e "saved.txt") || (-e "ip.txt")) {
+      my $ver=`ver`;
+      $ver=~s/^.*(Version.*)$/$1/s;
+      $ver=~s/^Version (10).*$/$1/;
+      $ver=~s/\s//sg;
+print "VERRR=$ver<==\n";
+      $ver=0 unless $ver=~/10/;
+print "VERSION=$ver\n";
       unless (-e "$keybasename.ppk") {
-         Wx::ExecuteCommand("puttykey \"$keybasename\" $path",wxEXEC_SYNC);
+         Wx::ExecuteCommand("puttykey \"$keybasename\" $path $ver",wxEXEC_SYNC);
       }
       if (exists $ENV{PAR_TEMP} && (-e "$ENV{PAR_TEMP}/inc")) {
          copy "$path/$keybasename.ppk", "$ENV{PAR_TEMP}/inc";
